pub struct DeclaredMethod<'a> {
pub module: &'a str,
pub name: &'a str,
pub entry: &'a FnEntry,
}Expand description
One method of a type, and the module whose source declares it.
Fields
module: &'a strThe module that declares this method: the type’s own, or one that conforms the type to a trait of its own.
name: &'a strThe method’s name.
entry: &'a FnEntryThe method itself, with the facts derived from it.